Authors
=======

* Lilatomic (`webpage <https://www.lilatomic.ca>`_, `lilatomic_github <https://github.com/lilatomic/>`_)

Template
--------

* Joao M. C. Teixeira (`webpage <https://bit.ly/joaomcteixeira>`_, `github <https://github.com/joaomcteixeira>`_)
